@@ -1,5 +1,5 @@
 package Games::2048::Input;
-use 5.01;
+use 5.012;
 use strictures;
 
 use if $^O eq "MSWin32", "Win32::Console::ANSI";
@@ -7,10 +7,10 @@ use Term::ReadKey;
 use Time::HiRes;
 
 END {
-	ReadMode 0; # reset read mode on exit
+	ReadMode 'normal';
 }
 
-ReadMode 4; # turn off control keys
+ReadMode 'cbreak';
 
 # manual and automatic window size updating
 my $_window_size;
@@ -18,10 +18,10 @@ eval { $SIG{WINCH} = \&update_window_size };
 &update_window_size;
 
 sub read_key {
-	state $keys = [];
+	state @keys;
 
-	if (@$keys) {
-		return shift @$keys;
+	if (@keys) {
+		return shift @keys;
 	}
 
 	my $char;
@@ -40,10 +40,10 @@ sub read_key {
 			.              # Otherwise just any character
 		)
 	)gsx) {
-		push @$keys, $1;
+		push @keys, $1;
 	}
 
-	return shift @$keys;
+	return shift @keys;
 }
 
 sub poll_key {
@@ -57,16 +57,17 @@ sub poll_key {
 
 sub key_vector {
 	my ($key) = @_;
-	state $vectors = [ [0, -1], [0, 1], [1, 0], [-1, 0] ];
-	state $keys = [ map "\e[$_", "A".."D" ];
+	state (@vectors, @keys);
+	@vectors = ( [0, -1], [0, 1], [1, 0], [-1, 0] );
+	@keys = map "\e[$_", "A".."D";
 	for (0..3) {
-		return $vectors->[$_] if $key eq $keys->[$_];
+		return $vectors[$_] if $key eq $keys[$_];
 	}
 	return;
 }
 
 sub update_window_size {
-	($_window_size) = GetTerminalSize *STDOUT;
+	($_window_size) = eval { GetTerminalSize *STDOUT };
 	$_window_size //= 80;
 }
 
